@@ -34,6 +34,15 @@ def value(obj, name):
     return getattr(obj, name) if (obj and hasattr(obj, name)) else None
 
 
+@register.filter
+def value_as_str(obj, name):
+    split = name.split('.', 1)
+    if len(split) > 1:
+        return value(getattr(obj, split[0]), split[1]) if (obj and hasattr(obj, split[0])) else None
+    as_str = value(obj, name + '_as_str')
+    return as_str() if as_str else value(obj, name)
+
+
 @register.filter
 def method(obj, name):
     split = name.split('.', 1)
