@@ -13,6 +13,17 @@ class Field:
         self.errors = []
         self.value_as_str = ''
         self.external = False
+        self.form = None
+
+    def attach(self, form):
+        self.form = form
+
+    def namespace(self):
+        return self.form.namespace if self.form else None
+
+    def full_name(self):
+        namespace = self.namespace()
+        return namespace + "_" + self.key if namespace else self.key
 
     def set(self, value):
         pass
@@ -52,7 +63,8 @@ class TextField(Field):
         self.value_as_str = value if value is not None else ''
 
     def read(self, context, default):
-        self.set(context[self.key] if self.key in context else default)
+        key = self.full_name()
+        self.set(context[key] if key in context else default)
 
     def validate(self):
         self.errors = []
@@ -82,7 +94,15 @@ class SelectField(Field):
         self.value_as_str = str(self.value)
 
     def read(self, context, default):
-        self.set(context[self.key] if self.key in context else default)
+        key = self.full_name()
+        self.set(context[key] if key in context else default)
+
+    def get_value(self, value):
+        if self.pairs:
+            keys = [k for k, v in self.pairs.items() if re.search(v, value, re.IGNORECASE)]
+            if len(keys) == 1:
+                return keys[0]
+        return value
 
 
 class IntegerField(Field):
@@ -98,12 +118,13 @@ class IntegerField(Field):
         self.value_as_str = '' if value is None else str(value)
 
     def read(self, context, default):
-        if self.key in context:
+        key = self.full_name()
+        if key in context:
             try:
-                self.value = int(context[self.key])
+                self.value = int(context[key])
             except ValueError:
                 self.value = None
-            self.value_as_str = str(context[self.key])
+            self.value_as_str = str(context[key])
         else:
             self.set(default)
 
@@ -133,9 +154,10 @@ class FloatField(Field):
         self.value_as_str = '' if value is None else str(value).replace('.', ',')
 
     def read(self, context, default):
-        if self.key in context:
-            self.value = to_float(context[self.key])
-            self.value_as_str = str(context[self.key])
+        key = self.full_name()
+        if key in context:
+            self.value = to_float(context[key])
+            self.value_as_str = str(context[key])
         else:
             self.set(default)
 
@@ -164,12 +186,13 @@ class DateField(Field):
         self.value_as_str = value.strftime(self.format) if value else ''
 
     def read(self, context, default):
-        if self.key in context:
+        key = self.full_name()
+        if key in context:
             try:
-                self.value = datetime.strptime(context[self.key], self.format)
+                self.value = datetime.strptime(context[key], self.format)
             except ValueError:
                 self.value = None
-            self.value_as_str = str(context[self.key])
+            self.value_as_str = str(context[key])
         else:
             self.set(default)
 
@@ -195,5 +218,6 @@ class BooleanField(Field):
         self.value_as_str = str(value)
 
     def read(self, context, default):
+        key = self.full_name()
         default_value = default if default is not None else False
-        self.set(self.key in context if len(context) > 0 else default_value)
+        self.set(key in context if len(context) > 0 else default_value)
