@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import io
 import os
+import pathlib
 import re
 import shutil
 import smtplib
@@ -508,8 +509,10 @@ def to_file(output, path):
 def upload(request, context, loader):
     file = request.FILES['upload']
 
+    extension = pathlib.Path(file.name).suffix
+
     uid = uuid.uuid4().hex
-    path = os.path.join(settings.MEDIA_ROOT, 'temp', uid)
+    path = os.path.join(settings.MEDIA_ROOT, 'temp', uid + extension)
     fs = FileSystemStorage()
     fs.save(path, file)
 
