@@ -9,7 +9,7 @@ from django.shortcuts import render
 from django.urls import reverse
 from django.utils.translation import gettext as _
 from foledol.django.logger import log
-from foledol.django.models import Grid, ConditionGroup, Condition, ORDER_BY_ASC, ORDER_BY_DESC
+from foledol.django.models import Grid, ConditionGroup, Condition, ORDER_BY_ASC, ORDER_BY_DESC, Column
 from foledol.django.reports.grid import GridReport
 from foledol.django.templatetags.form_extras import value, value_as_str
 from foledol.django.tools.field import TextField, DateField, BooleanField
@@ -43,11 +43,11 @@ class GridForm(Form):
 
 class ColumnSubTable(Table):
     def __init__(self, rows, read_only=False):
-        super().__init__(rows, [
+        super().__init__(Column, [
             TableColumn('label', "Libellé", method='label_as_str'),
             TableColumn('order_by', "Tri", method='order_by_as_str'),
             TableColumn('order', "Ordre")
-        ])
+        ], rows=rows)
         self.heading = 'Colonnes'
         self.update = 'django:column_update' if not read_only else None
         self.create = 'django:column_create' if not read_only else None
